@@ -54,6 +54,10 @@ setGeneric("getpars", function(object,which="pars",...) standardGeneric("getpars
 
 setGeneric("getmodel", function(object,...) standardGeneric("getmodel"))
 
+setGeneric("hessian", function(object, ...) standardGeneric("hessian"))
+
+setGeneric("standardError", function(object, ...) standardGeneric("standardError"))
+
 
 # functions 
 setGeneric("fit", function(object, ...) standardGeneric("fit"))
