@@ -42,8 +42,15 @@ function(response, prior, ...) {
 # this function is probably not ever called by users
 
 makeDepmix <-
-function(response, transition, prior, ntimes=NULL, stationary=TRUE, ...) {
-		
+function(response, transition, prior, ntimes=NULL, homogeneous=TRUE, stationary=NULL, ...) {	
+	
+	if(!(is.null(stationary))) {
+			homogeneous <- stationary
+			warning("Argument 'stationary' has been replaced by argument 'homogeneous' in 
+					version 1.3-0. In future versions argument 'stationary' will most likely be
+					used for other purposes.")
+	}
+	
 	nstates <- length(response)
 	nresp <- length(response[[1]])
 	
@@ -61,7 +68,7 @@ function(response, transition, prior, ntimes=NULL, stationary=TRUE, ...) {
 	
 	# make appropriate array for transition densities
 	nt <- sum(ntimes)
-	if(stationary) trDens <- array(0,c(1,nstates,nstates))
+	if(homogeneous) trDens <- array(0,c(1,nstates,nstates))
 	else trDens <- array(0,c(nt,nstates,nstates))
 	
 	# make appropriate array for response densities
@@ -82,7 +89,7 @@ function(response, transition, prior, ntimes=NULL, stationary=TRUE, ...) {
 	if(!(dim(init)[1]==length(ntimes))) stop("Argument 'ntimes' does not agree with dimension of prior model.")
 	
 	new("depmix",response=response,transition=transition,prior=prior,
-		dens=dens,trDens=trDens,init=init,stationary=stationary,
+		dens=dens,trDens=trDens,init=init,homogeneous=homogeneous,
 		ntimes=ntimes,nstates=nstates,nresp=nresp,npars=npars)
 	
 }
